@@ -9,20 +9,16 @@ from numpy import nan
 
 import pandas as pd
 
-from pandas import DataFrame, Index, Series, Timestamp
+from pandas import DataFrame, Index, Series, Timestamp, date_range
 from pandas.compat import lrange
 
 from pandas.tests.frame.common import TestData
 
 import pandas.util.testing as tm
-from pandas.util.testing import (assertRaisesRegexp,
-                                 assert_frame_equal,
-                                 assert_series_equal)
+from pandas.util.testing import assert_frame_equal, assert_series_equal
 
 
-class TestDataFrameConcatCommon(tm.TestCase, TestData):
-
-    _multiprocess_can_split_ = True
+class TestDataFrameConcatCommon(TestData):
 
     def test_concat_multiple_frames_dtypes(self):
 
@@ -79,12 +75,14 @@ class TestDataFrameConcatCommon(tm.TestCase, TestData):
         df = DataFrame(np.random.randn(5, 4),
                        columns=['foo', 'bar', 'baz', 'qux'])
 
-        series = df.ix[4]
-        with assertRaisesRegexp(ValueError, 'Indexes have overlapping values'):
+        series = df.loc[4]
+        with tm.assert_raises_regex(ValueError,
+                                    'Indexes have overlapping values'):
             df.append(series, verify_integrity=True)
         series.name = None
-        with assertRaisesRegexp(TypeError, 'Can only append a Series if '
-                                'ignore_index=True'):
+        with tm.assert_raises_regex(TypeError,
+                                    'Can only append a Series if '
+                                    'ignore_index=True'):
             df.append(series, verify_integrity=True)
 
         result = df.append(series[::-1], ignore_index=True)
@@ -99,10 +97,10 @@ class TestDataFrameConcatCommon(tm.TestCase, TestData):
         result = df.append(series[::-1][:3], ignore_index=True)
         expected = df.append(DataFrame({0: series[::-1][:3]}).T,
                              ignore_index=True)
-        assert_frame_equal(result, expected.ix[:, result.columns])
+        assert_frame_equal(result, expected.loc[:, result.columns])
 
         # can append when name set
-        row = df.ix[4]
+        row = df.loc[4]
         row.name = 5
         result = df.append(row)
         expected = df.append(df[-1:], ignore_index=True)
@@ -272,7 +270,7 @@ class TestDataFrameConcatCommon(tm.TestCase, TestData):
 
         other = DataFrame([[2., nan],
                            [nan, 7]], index=[1, 3], columns=[1, 2])
-        with assertRaisesRegexp(ValueError, "Data overlaps"):
+        with tm.assert_raises_regex(ValueError, "Data overlaps"):
             df.update(other, raise_conflict=True)
 
     def test_update_from_non_df(self):
@@ -305,7 +303,7 @@ class TestDataFrameConcatCommon(tm.TestCase, TestData):
 
         tst = A.join(C, on='aa')
 
-        self.assertEqual(len(tst.columns), 3)
+        assert len(tst.columns) == 3
 
     def test_join_multiindex_leftright(self):
         # GH 10741
@@ -421,13 +419,29 @@ class TestDataFrameConcatCommon(tm.TestCase, TestData):
         assert_frame_equal(concatted_1_series, expected_columns_series)
 
         # Testing ValueError
-        with assertRaisesRegexp(ValueError, 'No axis named'):
+        with tm.assert_raises_regex(ValueError, 'No axis named'):
             pd.concat([series1, series2], axis='something')
 
+    def test_concat_numerical_names(self):
+        # #15262  # #12223
+        df = pd.DataFrame({'col': range(9)},
+                          dtype='int32',
+                          index=(pd.MultiIndex
+                                 .from_product([['A0', 'A1', 'A2'],
+                                                ['B0', 'B1', 'B2']],
+                                               names=[1, 2])))
+        result = pd.concat((df.iloc[:2, :], df.iloc[-2:, :]))
+        expected = pd.DataFrame({'col': [0, 1, 7, 8]},
+                                dtype='int32',
+                                index=pd.MultiIndex.from_tuples([('A0', 'B0'),
+                                                                 ('A0', 'B1'),
+                                                                 ('A2', 'B1'),
+                                                                 ('A2', 'B2')],
+                                                                names=[1, 2]))
+        tm.assert_frame_equal(result, expected)
 
-class TestDataFrameCombineFirst(tm.TestCase, TestData):
 
-    _multiprocess_can_split_ = True
+class TestDataFrameCombineFirst(TestData):
 
     def test_combine_first_mixed(self):
         a = Series(['a', 'b'], index=lrange(2))
@@ -450,7 +464,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
         combined = head.combine_first(tail)
         reordered_frame = self.frame.reindex(combined.index)
         assert_frame_equal(combined, reordered_frame)
-        self.assertTrue(tm.equalContents(combined.columns, self.frame.columns))
+        assert tm.equalContents(combined.columns, self.frame.columns)
         assert_series_equal(combined['A'], reordered_frame['A'])
 
         # same index
@@ -464,7 +478,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
 
         combined = fcopy.combine_first(fcopy2)
 
-        self.assertTrue((combined['A'] == 1).all())
+        assert (combined['A'] == 1).all()
         assert_series_equal(combined['B'], fcopy['B'])
         assert_series_equal(combined['C'], fcopy2['C'])
         assert_series_equal(combined['D'], fcopy['D'])
@@ -474,12 +488,12 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
         head['A'] = 1
 
         combined = head.combine_first(tail)
-        self.assertTrue((combined['A'][:10] == 1).all())
+        assert (combined['A'][:10] == 1).all()
 
         # reverse overlap
         tail['A'][:10] = 0
         combined = tail.combine_first(head)
-        self.assertTrue((combined['A'][:10] == 0).all())
+        assert (combined['A'][:10] == 0).all()
 
         # no overlap
         f = self.frame[:10]
@@ -496,13 +510,13 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
         assert_frame_equal(comb, self.frame)
 
         comb = self.frame.combine_first(DataFrame(index=["faz", "boo"]))
-        self.assertTrue("faz" in comb.index)
+        assert "faz" in comb.index
 
         # #2525
         df = DataFrame({'a': [1]}, index=[datetime(2012, 1, 1)])
         df2 = DataFrame({}, columns=['b'])
         result = df.combine_first(df2)
-        self.assertTrue('b' in result)
+        assert 'b' in result
 
     def test_combine_first_mixed_bug(self):
         idx = Index(['a', 'b', 'c', 'e'])
@@ -524,7 +538,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
                             "col5": ser3})
 
         combined = frame1.combine_first(frame2)
-        self.assertEqual(len(combined.columns), 5)
+        assert len(combined.columns) == 5
 
         # gh 3016 (same as in update)
         df = DataFrame([[1., 2., False, True], [4., 5., True, False]],
@@ -534,9 +548,9 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
         result = df.combine_first(other)
         assert_frame_equal(result, df)
 
-        df.ix[0, 'A'] = np.nan
+        df.loc[0, 'A'] = np.nan
         result = df.combine_first(other)
-        df.ix[0, 'A'] = 45
+        df.loc[0, 'A'] = 45
         assert_frame_equal(result, df)
 
         # doc example
@@ -589,28 +603,28 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
         dfa = pd.DataFrame([[pd.Timestamp('2011-01-01'), 2]],
                            columns=['a', 'b'])
         dfb = pd.DataFrame([[4], [5]], columns=['b'])
-        self.assertEqual(dfa['a'].dtype, 'datetime64[ns]')
-        self.assertEqual(dfa['b'].dtype, 'int64')
+        assert dfa['a'].dtype == 'datetime64[ns]'
+        assert dfa['b'].dtype == 'int64'
 
         res = dfa.combine_first(dfb)
         exp = pd.DataFrame({'a': [pd.Timestamp('2011-01-01'), pd.NaT],
                             'b': [2., 5.]}, columns=['a', 'b'])
         tm.assert_frame_equal(res, exp)
-        self.assertEqual(res['a'].dtype, 'datetime64[ns]')
+        assert res['a'].dtype == 'datetime64[ns]'
         # ToDo: this must be int64
-        self.assertEqual(res['b'].dtype, 'float64')
+        assert res['b'].dtype == 'float64'
 
         res = dfa.iloc[:0].combine_first(dfb)
         exp = pd.DataFrame({'a': [np.nan, np.nan],
                             'b': [4, 5]}, columns=['a', 'b'])
         tm.assert_frame_equal(res, exp)
         # ToDo: this must be datetime64
-        self.assertEqual(res['a'].dtype, 'float64')
+        assert res['a'].dtype == 'float64'
         # ToDo: this must be int64
-        self.assertEqual(res['b'].dtype, 'int64')
+        assert res['b'].dtype == 'int64'
 
     def test_combine_first_timezone(self):
-        # GH 7630
+        # see gh-7630
         data1 = pd.to_datetime('20100101 01:01').tz_localize('UTC')
         df1 = pd.DataFrame(columns=['UTCdatetime', 'abc'],
                            data=data1,
@@ -630,10 +644,10 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
                            index=pd.date_range('20140627', periods=2,
                                                freq='D'))
         tm.assert_frame_equal(res, exp)
-        self.assertEqual(res['UTCdatetime'].dtype, 'datetime64[ns, UTC]')
-        self.assertEqual(res['abc'].dtype, 'datetime64[ns, UTC]')
+        assert res['UTCdatetime'].dtype == 'datetime64[ns, UTC]'
+        assert res['abc'].dtype == 'datetime64[ns, UTC]'
 
-        # GH 10567
+        # see gh-10567
         dts1 = pd.date_range('2015-01-01', '2015-01-05', tz='UTC')
         df1 = pd.DataFrame({'DATE': dts1})
         dts2 = pd.date_range('2015-01-03', '2015-01-05', tz='UTC')
@@ -641,7 +655,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
 
         res = df1.combine_first(df2)
         tm.assert_frame_equal(res, df1)
-        self.assertEqual(res['DATE'].dtype, 'datetime64[ns, UTC]')
+        assert res['DATE'].dtype == 'datetime64[ns, UTC]'
 
         dts1 = pd.DatetimeIndex(['2011-01-01', 'NaT', '2011-01-03',
                                  '2011-01-04'], tz='US/Eastern')
@@ -666,7 +680,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
         # if df1 doesn't have NaN, keep its dtype
         res = df1.combine_first(df2)
         tm.assert_frame_equal(res, df1)
-        self.assertEqual(res['DATE'].dtype, 'datetime64[ns, US/Eastern]')
+        assert res['DATE'].dtype == 'datetime64[ns, US/Eastern]'
 
         dts1 = pd.date_range('2015-01-01', '2015-01-02', tz='US/Eastern')
         df1 = pd.DataFrame({'DATE': dts1})
@@ -679,7 +693,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
                    pd.Timestamp('2015-01-03')]
         exp = pd.DataFrame({'DATE': exp_dts})
         tm.assert_frame_equal(res, exp)
-        self.assertEqual(res['DATE'].dtype, 'object')
+        assert res['DATE'].dtype == 'object'
 
     def test_combine_first_timedelta(self):
         data1 = pd.TimedeltaIndex(['1 day', 'NaT', '3 day', '4day'])
@@ -692,7 +706,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
                                      '11 day', '3 day', '4 day'])
         exp = pd.DataFrame({'TD': exp_dts}, index=[1, 2, 3, 4, 5, 7])
         tm.assert_frame_equal(res, exp)
-        self.assertEqual(res['TD'].dtype, 'timedelta64[ns]')
+        assert res['TD'].dtype == 'timedelta64[ns]'
 
     def test_combine_first_period(self):
         data1 = pd.PeriodIndex(['2011-01', 'NaT', '2011-03',
@@ -708,7 +722,7 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
                                  freq='M')
         exp = pd.DataFrame({'P': exp_dts}, index=[1, 2, 3, 4, 5, 7])
         tm.assert_frame_equal(res, exp)
-        self.assertEqual(res['P'].dtype, 'object')
+        assert res['P'].dtype == 'object'
 
         # different freq
         dts2 = pd.PeriodIndex(['2012-01-01', '2012-01-02',
@@ -724,4 +738,28 @@ class TestDataFrameCombineFirst(tm.TestCase, TestData):
                    pd.Period('2011-04', freq='M')]
         exp = pd.DataFrame({'P': exp_dts}, index=[1, 2, 3, 4, 5, 7])
         tm.assert_frame_equal(res, exp)
-        self.assertEqual(res['P'].dtype, 'object')
+        assert res['P'].dtype == 'object'
+
+    def test_combine_first_int(self):
+        # GH14687 - integer series that do no align exactly
+
+        df1 = pd.DataFrame({'a': [0, 1, 3, 5]}, dtype='int64')
+        df2 = pd.DataFrame({'a': [1, 4]}, dtype='int64')
+
+        res = df1.combine_first(df2)
+        tm.assert_frame_equal(res, df1)
+        assert res['a'].dtype == 'int64'
+
+    def test_concat_datetime_datetime64_frame(self):
+        # #2624
+        rows = []
+        rows.append([datetime(2010, 1, 1), 1])
+        rows.append([datetime(2010, 1, 2), 'hi'])
+
+        df2_obj = DataFrame.from_records(rows, columns=['date', 'test'])
+
+        ind = date_range(start="2000/1/1", freq="D", periods=10)
+        df1 = DataFrame({'date': ind, 'test': lrange(10)})
+
+        # it works!
+        pd.concat([df1, df2_obj])
